#pragma once

enum kysec_admctl_user_type {
    KYSEC_ADMIN_USER,    /* root用户 */
    KYSEC_SECADM_USER,   /* secadm用户 */
    KYSEC_AUDITADM_USER, /* auditadm 用户 */

};

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 将程序添加到所有用户无法执行的黑名单中.
 * @param path 程序路径
 * @return 0:成功  其他:失败
 */
int kysec_scene_admctl_add_path_for_deny_all_user(const char *path);

/**
 * @brief 将程序从所有用户无法执行的黑名单中删除
 * @param path 程序路径
 * @return 0:成功  其他:失败
 */
int kysec_scene_admctl_remove_path_from_deny_all_user(const char *path);

/**
 * @brief 获取所有用户无法执行的黑名单程序
 * @return 字符串数组  NULL:无数据
 *         调用者使用完需要手动释放内存
 */
char **kysec_scene_admctl_get_deny_all_policy(int *count);

/**
 * @brief 为用户设置能够执行的黑名单中的程序
 * @param user  用户
 * @param path  黑名单中的程序路径
 *        path 必须在所有用户无法执行的黑名单中存在
 * @return 0:成功 其他:失败
 */
int kysec_scene_admctl_add_path_for_user(enum kysec_admctl_user_type user,
                                         const char *path);

/**
 * @brief 为用户删除可执行黑名单中的程序
 * @param user  用户
 * @param path  程序路径
 *        path 必须在所有用户无法执行的黑名单中存在
 * @return 0:成功 其他:失败
 */
int kysec_scene_admctl_remove_path_from_user(enum kysec_admctl_user_type user,
                                             const char *path);

/**
 * @brief 获取用户的可执行黑名单中的程序
 * @param user  用户
 * @param count 个数
 * @return 字符数组 NULL:无数据
 *         调用者使用完需要手动释放内存
 */
char **kysec_scene_admctl_get_user_policy(enum kysec_admctl_user_type user,
                                          int *count);

#ifdef __cplusplus
}
#endif
