#pragma once

#include "scene_common.h"

/**
 * @brief 文件保护箱可设置的状态
 */
enum kysec_scene_box_attr {
    /**
     * @brief 不隐藏
     */
    BOX_UNHIDE,

    /**
     * @brief 隐藏
     */
    BOX_HIDE,
};

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 设置某个文件保护箱的属性
 * @detail 如果同用户同名的文件保护箱已存在，设置对应的属性为`attr`
 *         如果同用户同名的文件保护箱不存在，添加一个对应的保护箱并设置属性为`attr`
 * @param username[in] 用户箱用户，保护箱位于哪个用户下
 * @param box_name[in] 保护箱名称
 * @param attr[in] 设置的属性
 * @return 0:成功 其他:失败
 */
int kysec_scene_box_set_attr(const char *username, const char *box_name, enum kysec_scene_box_attr attr);

/**
 * @brief 查看某个文件保护箱的属性
 * @param username[in] 用户箱用户，保护箱位于哪个用户下
 * @param box_name[in] 保护箱名称
 * @return >=0: 文件保护箱的属性 <0:失败
 */
enum kysec_scene_box_attr kysec_scene_box_get_attr(const char * username, const char *box_name);

/**
 * @brief 删除某个文件保护箱
 * @param username[in] 用户箱用户，保护箱位于哪个用户下
 * @param box_name[in] 保护箱名称
 * @return 0:成功 其他:失败
 */
int kysec_scene_box_remove_box(const char* username, const char* box_name);

#ifdef __cplusplus
}
#endif
