#pragma once

enum kysec_scene_netctl_operate_type {
    /* 允许 */
    KYSEC_NETCTL_ALLOW = 1,
    /* 拒绝 */
    KYSEC_NETCTL_DENY,
    KYSEC_NETCTL_ALARM,
};

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 根据路径添加网络管控策略
 * @param path  程序路径
 * @return 0:成功 其他:失败
 *
 */
int kysec_scene_netctl_add_by_path(const char *path);

/**
 * @brief 根据路径删除网络管控策略
 * @param path  程序路径
 * @return 0:成功 其他:失败
 *
 */
int kysec_scene_netctl_remove_by_path(const char *path);

/**
 * @brief 获取路径的网络管控策略
 * @param count[in]  个数
 * @return 字符串数组 NULL:无数据
 *         调用者使用完需要手动释放内存
 *
 */
char **kysec_scene_netctl_get_path_policy(int *count);

/**
 * @brief 根据应用包名添加网络管控策略
 * @param package  应用包名称
 * @return 0:成功 其他:失败
 *
 */
int kysec_scene_netctl_add_by_package(const char *package);

/**
 * @brief 根据应用包名删除网络管控策略
 * @param package  应用包名称
 * @return 0:成功 其他:失败
 *
 */
int kysec_scene_netctl_remove_by_package(const char *package);

/**
 * @brief 获取应用包网络管控策略
 * @param count[in]  个数
 * @return 字符串数组 NULL:无数据
 *         调用者使用完需要手动释放内存
 *
 */
char **kysec_scene_netctl_get_package_policy(int *count);

/**
 * @brief 将路径或软件包添加到永不提示授权弹框列表中
 * @param path_or_pkg
 * @return 0:成功 其他:失败
 */
int kysec_scene_netctl_add_path_or_pkg_to_no_alarm(const char *path_or_pkg);

/**
 * @brief 将路径或软件包从永不提示授权弹框列表中删除
 * @param path_or_pkg
 * @return 0:成功 其他:失败
 */
int kysec_scene_netctl_remove_path_or_pkg_from_no_alarm(
    const char *path_or_pkg);

/**
 * @brief 获取对应路径是否在已允许或已拒绝的策略列表中
 * @param path_or_pkg  程序绝对路径或软件包名称
 * @return 0:不存在 1:存在
 */
int kysec_scene_netctl_path_or_pkg_exists_in_no_alarm(const char *path_or_pkg);

#ifdef __cplusplus
}
#endif
