#pragma once

enum static_measure_checkpoint_type {
    STATIC_MEASURE_READ_CHECKPOINT = 1, /* read  */
    STATIC_MEASURE_WRITE_CHECKPOINT,    /* write */
    STATIC_MEASURE_EXEC_CHECKPOINT,     /* exec  */

};

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief  添加静态度量文件
 * @param  path 文件或目录的绝对路径
 * @return 0:成功 非0:失败
 */
int kysec_scene_static_measure_add_by_path(const char *path);

/**
 * @brief  删除静态度量文件
 * @param  path 文件或目录的绝对路径
 * @return 0:成功 非0:失败
 */
int kysec_scene_static_measure_remove_by_path(const char *path);

/**
 * @brief  获取静态度量策略
 * @param  count 个数
 * @return 字符串数组  NULL:无数据
 *         调用者使用完需要手动释放内存
 */
char **kysec_scene_static_measure_get_policy_for_path(int *count);

/**
 * @brief  添加静态度量检查点策略
 * @param  checkpoint 检查点
 * @return 0:成功 其他:失败
 */
int kysec_scene_static_measure_add_by_checkpoint(
    enum static_measure_checkpoint_type checkpoint);

/**
 * @brief  删除静态度量检查点策略
 * @param  checkpoint 检查点
 * @return 0:成功 其他:失败
 */
int kysec_scene_static_measure_remove_by_checkpoint(
    enum static_measure_checkpoint_type checkpoint);

/**
 * @brief  获取静态度量检查点策略
 * @param  count 个数
 * @return 字符串数组 NULL:无数据
 *         调用者使用完需要手动释放内存
 */
char **kysec_scene_static_measure_get_policy_for_checkpoint(int *count);

/**
 * @brief  添加内核模块文件的静态度量策略
 * @param  path 内核模块文件绝对路径
 * @return 0:成功 其他:失败
 */

int kysec_scene_static_measure_add_by_kmod_file(const char *path);

/**
 * @brief  删除内核模块文件的静态度量策略
 * @param  path 内核模块文件绝对路径
 * @return 0:成功 其他:失败
 */
int kysec_scene_static_measure_remove_by_kmod_file(const char *path);

/**
 * @brief  获取静态度量的内核文件策略
 * @param  count 个数
 * @return 字符串数据 NULL:无数据
 *         调用者使用完需要手动释放内存
 */
char **kysec_scene_static_measure_get_policy_for_kmod_file(int *count);
#ifdef __cplusplus
}
#endif
